Struct ZwlrOutputModeV1
pub struct ZwlrOutputModeV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
output mode
This object describes an output mode.
Some heads don’t support output modes, in which case modes won’t be advertised.
Properties sent via this interface are applied atomically via the wlr_output_manager.done event. No guarantees are made regarding the order in which properties are sent.
See also the Event enum for this interface.
Implementations
impl ZwlrOutputModeV1
impl ZwlrOutputModeV1
pub fn release(&self)
pub fn release(&self)
destroy the mode object
This request indicates that the client will no longer use this mode object.